==> jc-1.4.0.tar.gz: soot/shimple/internal/analysis/DominatorsFinder.h <==
// public class soot.shimple.internal.analysis.DominatorsFinder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d5d9fd40a0d98b0a soot_shimple_internal_analysis_DominatorsFinder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_shimple_internal_analysis_DominatorsFinder_H_
#define _JC_soot_shimple_internal_analysis_DominatorsFinder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_toolkits_graph_Block$object;
struct _jc_soot_toolkits_graph_BlockGraph$object;

// Typedefs
typedef struct _jc_soot_shimple_internal_analysis_DominatorsFinder$sub_refs	_jc_soot_shimple_internal_analysis_DominatorsFinder$sub_refs;
typedef struct _jc_soot_shimple_internal_analysis_DominatorsFinder$sub_nonrefs	_jc_soot_shimple_internal_analysis_DominatorsFinder$sub_nonrefs;
typedef struct _jc_soot_shimple_internal_analysis_DominatorsFinder$refs	_jc_soot_shimple_internal_analysis_DominatorsFinder$refs;
typedef struct _jc_soot_shimple_internal_analysis_DominatorsFinder$nonrefs	_jc_soot_shimple_internal_analysis_DominatorsFinder$nonrefs;
typedef struct _jc_soot_shimple_internal_analysis_DominatorsFinder$object	_jc_soot_shimple_internal_analysis_DominatorsFinder$object;

typedef const struct _jc_soot_shimple_internal_analysis_DominatorsFinder$vmethods	_jc_soot_shimple_internal_analysis_DominatorsFinder$vmethods;
typedef const struct _jc_soot_shimple_internal_analysis_DominatorsFinder$vtable	_jc_soot_shimple_internal_analysis_DominatorsFinder$vtable;
typedef const struct _jc_soot_shimple_internal_analysis_DominatorsFinder$vtype	_jc_soot_shimple_internal_analysis_DominatorsFinder$vtype;

// Constructors
extern void _jc_soot_shimple_internal_analysis_DominatorsFinder$method$_init$6d442eef553ff081(_jc_env *, struct _jc_soot_shimple_internal_analysis_DominatorsFinder$object *, struct _jc_soot_toolkits_graph_BlockGraph$object *);

// Virtual methods
extern struct _jc_object *_jc_soot_shimple_internal_analysis_DominatorsFinder$method$getDominators$7a175d9aece4d06e(_jc_env *, struct _jc_soot_shimple_internal_analysis_DominatorsFinder$object *, struct _jc_soot_toolkits_graph_Block$object *);
extern jboolean _jc_soot_shimple_internal_analysis_DominatorsFinder$method$isDominatedBy$da7aa8abc15f5dd4(_jc_env *, struct _jc_soot_shimple_internal_analysis_DominatorsFinder$object *, struct _jc_soot_toolkits_graph_Block$object *, struct _jc_soot_toolkits_graph_Block$object *);
extern jboolean _jc_soot_shimple_internal_analysis_DominatorsFinder$method$isDominatedByAll$83266715d960591f(_jc_env *, struct _jc_soot_shimple_internal_analysis_DominatorsFinder$object *, struct _jc_soot_toolkits_graph_Block$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_internal_analysis_DominatorsFinder$method_info$getDominators$7a175d9aece4d06e;
extern _jc_method _jc_soot_shimple_internal_analysis_DominatorsFinder$method_info$isDominatedBy$da7aa8abc15f5dd4;
extern _jc_method _jc_soot_shimple_internal_analysis_DominatorsFinder$method_info$isDominatedByAll$83266715d960591f;

// Virtual methods structure
struct _jc_soot_shimple_internal_analysis_DominatorsFinder$vmethods {
	struct _jc_object	*(*getDominators$7a175d9aece4d06e)(_jc_env *, struct _jc_soot_shimple_internal_analysis_DominatorsFinder$object *, struct _jc_soot_toolkits_graph_Block$object *);
	jboolean	(*isDominatedBy$da7aa8abc15f5dd4)(_jc_env *, struct _jc_soot_shimple_internal_analysis_DominatorsFinder$object *, struct _jc_soot_toolkits_graph_Block$object *, struct _jc_soot_toolkits_graph_Block$object *);
	jboolean	(*isDominatedByAll$83266715d960591f)(_jc_env *, struct _jc_soot_shimple_internal_analysis_DominatorsFinder$object *, struct _jc_soot_toolkits_graph_Block$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_shimple_internal_analysis_DominatorsFinder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_shimple_internal_analysis_DominatorsFinder$vmethods	soot_shimple_internal_analysis_DominatorsFinder;
};

// Vtype
struct _jc_soot_shimple_internal_analysis_DominatorsFinder$vtype {
	_jc_type			type;
	_jc_soot_shimple_internal_analysis_DominatorsFinder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_internal_analysis_DominatorsFinder$sub_refs {
	struct _jc_object	*blockToDominators;
};

// Reference instance fields (object)
struct _jc_soot_shimple_internal_analysis_DominatorsFinder$refs {
    _jc_soot_shimple_internal_analysis_DominatorsFinder$sub_refs	soot_shimple_internal_analysis_DominatorsFinder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_internal_analysis_DominatorsFinder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_internal_analysis_DominatorsFinder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_shimple_internal_analysis_DominatorsFinder$sub_nonrefs	soot_shimple_internal_analysis_DominatorsFinder;
};

// Object instance structure
struct _jc_soot_shimple_internal_analysis_DominatorsFinder$object {
	_jc_soot_shimple_internal_analysis_DominatorsFinder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_internal_analysis_DominatorsFinder$vtype	*vtype;
	_jc_soot_shimple_internal_analysis_DominatorsFinder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_internal_analysis_DominatorsFinder$vtype _jc_soot_shimple_internal_analysis_DominatorsFinder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_internal_analysis_DominatorsFinder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_internal_analysis_DominatorsFinder$class_object;

#endif	/* _JC_soot_shimple_internal_analysis_DominatorsFinder_H_ */

==> jc-1.4.6.tar.gz: soot/shimple/internal/analysis/DominatorsFinder.h <==
// public class soot.shimple.internal.analysis.DominatorsFinder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d5d9fd40a0d98b0a soot_shimple_internal_analysis_DominatorsFinder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_shimple_internal_analysis_DominatorsFinder_H_
#define _JC_soot_shimple_internal_analysis_DominatorsFinder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_toolkits_graph_Block$object;
struct _jc_soot_toolkits_graph_BlockGraph$object;

// Typedefs
typedef struct _jc_soot_shimple_internal_analysis_DominatorsFinder$sub_refs	_jc_soot_shimple_internal_analysis_DominatorsFinder$sub_refs;
typedef struct _jc_soot_shimple_internal_analysis_DominatorsFinder$sub_nonrefs	_jc_soot_shimple_internal_analysis_DominatorsFinder$sub_nonrefs;
typedef struct _jc_soot_shimple_internal_analysis_DominatorsFinder$refs	_jc_soot_shimple_internal_analysis_DominatorsFinder$refs;
typedef struct _jc_soot_shimple_internal_analysis_DominatorsFinder$nonrefs	_jc_soot_shimple_internal_analysis_DominatorsFinder$nonrefs;
typedef struct _jc_soot_shimple_internal_analysis_DominatorsFinder$object	_jc_soot_shimple_internal_analysis_DominatorsFinder$object;

typedef const struct _jc_soot_shimple_internal_analysis_DominatorsFinder$vmethods	_jc_soot_shimple_internal_analysis_DominatorsFinder$vmethods;
typedef const struct _jc_soot_shimple_internal_analysis_DominatorsFinder$vtable	_jc_soot_shimple_internal_analysis_DominatorsFinder$vtable;
typedef const struct _jc_soot_shimple_internal_analysis_DominatorsFinder$vtype	_jc_soot_shimple_internal_analysis_DominatorsFinder$vtype;

// Constructors
extern void _jc_soot_shimple_internal_analysis_DominatorsFinder$method$_init$6d442eef553ff081(_jc_env *, struct _jc_soot_shimple_internal_analysis_DominatorsFinder$object *, struct _jc_soot_toolkits_graph_BlockGraph$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_shimple_internal_analysis_DominatorsFinder$method$getDominators$7a175d9aece4d06e(_jc_env *, struct _jc_soot_shimple_internal_analysis_DominatorsFinder$object *, struct _jc_soot_toolkits_graph_Block$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_shimple_internal_analysis_DominatorsFinder$method$isDominatedBy$da7aa8abc15f5dd4(_jc_env *, struct _jc_soot_shimple_internal_analysis_DominatorsFinder$object *, struct _jc_soot_toolkits_graph_Block$object *, struct _jc_soot_toolkits_graph_Block$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_shimple_internal_analysis_DominatorsFinder$method$isDominatedByAll$83266715d960591f(_jc_env *, struct _jc_soot_shimple_internal_analysis_DominatorsFinder$object *, struct _jc_soot_toolkits_graph_Block$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_internal_analysis_DominatorsFinder$method_info$getDominators$7a175d9aece4d06e;
extern _jc_method _jc_soot_shimple_internal_analysis_DominatorsFinder$method_info$isDominatedBy$da7aa8abc15f5dd4;
extern _jc_method _jc_soot_shimple_internal_analysis_DominatorsFinder$method_info$isDominatedByAll$83266715d960591f;

// Virtual methods structure
struct _jc_soot_shimple_internal_analysis_DominatorsFinder$vmethods {
	struct _jc_object	*(*getDominators$7a175d9aece4d06e)(_jc_env *, struct _jc_soot_shimple_internal_analysis_DominatorsFinder$object *, struct _jc_soot_toolkits_graph_Block$object *) _JC_JCNI_ATTR;
	jboolean	(*isDominatedBy$da7aa8abc15f5dd4)(_jc_env *, struct _jc_soot_shimple_internal_analysis_DominatorsFinder$object *, struct _jc_soot_toolkits_graph_Block$object *, struct _jc_soot_toolkits_graph_Block$object *) _JC_JCNI_ATTR;
	jboolean	(*isDominatedByAll$83266715d960591f)(_jc_env *, struct _jc_soot_shimple_internal_analysis_DominatorsFinder$object *, struct _jc_soot_toolkits_graph_Block$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_shimple_internal_analysis_DominatorsFinder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_shimple_internal_analysis_DominatorsFinder$vmethods	soot_shimple_internal_analysis_DominatorsFinder;
};

// Vtype
struct _jc_soot_shimple_internal_analysis_DominatorsFinder$vtype {
	_jc_type			type;
	_jc_soot_shimple_internal_analysis_DominatorsFinder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_internal_analysis_DominatorsFinder$sub_refs {
	struct _jc_object	*blockToDominators;
};

// Reference instance fields (object)
struct _jc_soot_shimple_internal_analysis_DominatorsFinder$refs {
    _jc_soot_shimple_internal_analysis_DominatorsFinder$sub_refs	soot_shimple_internal_analysis_DominatorsFinder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_internal_analysis_DominatorsFinder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_internal_analysis_DominatorsFinder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_shimple_internal_analysis_DominatorsFinder$sub_nonrefs	soot_shimple_internal_analysis_DominatorsFinder;
};

// Object instance structure
struct _jc_soot_shimple_internal_analysis_DominatorsFinder$object {
	_jc_soot_shimple_internal_analysis_DominatorsFinder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_internal_analysis_DominatorsFinder$vtype	*vtype;
	_jc_soot_shimple_internal_analysis_DominatorsFinder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_internal_analysis_DominatorsFinder$vtype _jc_soot_shimple_internal_analysis_DominatorsFinder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_internal_analysis_DominatorsFinder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_internal_analysis_DominatorsFinder$class_object;

#endif	/* _JC_soot_shimple_internal_analysis_DominatorsFinder_H_ */
